@@ -1,6 +1,6 @@
 diff.ff <- function(x, ...){
   #TODO generalize for lag and difference
-  chunks <- chunk(x, by=2)
+  chunks <- chunk(x, ...)
   
   # hmm, next line may go wrong for small datatypes...
   d <- ff(vmode=vmode(x), length=length(x)-1)
